@@ -29,22 +29,22 @@ fi
 
 RSTFILES=(
   ". lazarusidestrconsts lazaruside"
+  ". debuggerstrconst"
+  ". gdbmidebugger"
   "ideintf objinspstrconsts"
   "components/codetools codetoolsstrconsts"
-  "components/synedit syneditstrconst synedit"
-  "components/synedit synmacrorecorder"
-  "components/synedit synhighlighterunixshellscript"
   "components/tdbf registerdbf"
   "components/turbopower_ipro ipconst"
   "components/turbopower_ipro iputils"
-  "components/cgi cgimodules"
   "components/lazreport/samples/editor maincalleditor calleditorwithpkg"
   "components/memds frmselectdataset"
-  "components/messagecomposer messagecomposer"  
   "components/printers/design ideprinting"
   "components/projecttemplates projecttemplates"
   "components/projecttemplates frmtemplatevariables"
   "components/projecttemplates idetemplateproject"
+  "tools/lazdatadesktop lazdatadeskstr lazdatadesktop"
+  "doceditor lazdemsg lazde"
+  "examples/lazresexplorer reconstsunit resexplorer"
   "lcl lclstrconsts"
 )  
 
