@@ -2,61 +2,95 @@
 #
 # Author: Mattias Gaertner
 #
-# Usage: ./create_lazarus_deb.sh [gtk1] [append-revision]
+# Usage: ./create_lazarus_deb.sh [gtk1] [append-revision] [chmhelp]
 #
 #   Options:
-#     gtk1              compile IDE and programs for gtk1 too. gtk2 ppu are still built.
+#     gtk1              compile IDE and programs for gtk1.
+#     qt                compile IDE and programs for qt.
 #     append-revision   append the svn revision to the .deb version
+#     chmhelp           add package chmhelp and add chm,kwd,xct,txt files in docs/chm
 
-set -x
 set -e
 
 LCLWidgetset=
-if [ "$1" = "gtk1" ]; then
-  LCLWidgetset=gtk
-  shift
-fi
-
 LazVersionPostfix=
-if [ "$1" = "append-revision" ]; then
-  LazVersionPostfix=$(./get_svn_revision_number.sh .)
-  if [ -n "$LazVersionPostfix" ]; then
-    LazVersionPostfix=.$LazVersionPostfix
-  fi
-  shift
-fi
+UseCHMHelp=
+LazRelease='0'
 
-if [ -n "$1" ]; then
-  echo "Usage: ./create_lazarus_deb.sh [gtk1] [release=svn]"
-  exit
-fi
+while [ $# -gt 0 ]; do
+  echo "param=$1"
+  case "$1" in
+  gtk1)
+    echo "Compile for gtk1"
+    if [ -n "$LCLWidgetset" ]; then
+      echo "widgetset already set to $LCLWidgetset"
+      exit -1
+    fi
+    LCLWidgetset=gtk
+    LazVersionPostfix=${LazVersionPostfix}-gtk
+    ;;
+
+  qt)
+    echo "Compile for qt"
+    if [ -n "$LCLWidgetset" ]; then
+      echo "widgetset already set to $LCLWidgetset"
+      exit -1
+    fi
+    LCLWidgetset=qt
+    LazVersionPostfix=${LazVersionPostfix}-qt
+    ;;
+
+  append-revision)
+    LazRevision=$(./get_svn_revision_number.sh .)
+    if [ -n "$LazRevision" ]; then
+      LazVersionPostfix=$LazVersionPostfix.$LazRevision
+    fi
+    echo "Appending svn revision $LazVersionPostfix to deb name"
+    ;;
+
+  chmhelp)
+    echo "using package chmhelp"
+    UseCHMHelp=1
+    ;;
+
+  *)
+    echo "invalid parameter $1"
+    echo "Usage: ./create_lazarus_deb.sh [chmhelp] [gtk1] [qt] [qtlib=<dir>] [release=svn] "
+    exit 1
+    ;;
+  esac
+  shift
+done
 
 # get FPC version
 FPCVersion=$(fpc -v | grep 'Compiler version' | sed 's/.*\([0-9]\.[0-9]\.[0-9]\).*/\1/')
+echo "FPCVersion=$FPCVersion"
 
-Arch=`dpkg --print-architecture` 
-if [  "$Arch" = i386 ]; then 
-  ppcbin=ppc386 
-else 
+Arch=`dpkg --print-architecture`
+echo "debian architecture=$Arch"
+targetos=$Arch
+if [  "$Arch" = i386 ]; then
+  ppcbin=ppc386
+else
   if [ "$Arch" = amd64 ]; then 
     ppcbin=ppcx64 
-  else   
+    targetos=x86_64
+  else
     if [  "$Arch" = powerpc ]; then 
       ppcbin=ppcppc 
-    else 
+    else
       if [  "$Arch" = sparc ]; then 
         ppcbin=ppcsparc 
-      else 
+      else
         echo "$Arch is not supported." 
         exit -1 
       fi 
     fi 
   fi 
-fi 
+fi
 
 Date=`date +%Y%m%d`
 LazVersion=$(./get_lazarus_version.sh)$LazVersionPostfix
-LazRelease='0'
 SrcTGZ=lazarus-$LazVersion-$LazRelease.tar.gz
 CurDir=`pwd`
 TmpDir=~/tmp/lazarus$LazVersion
@@ -64,12 +98,18 @@ LazBuildDir=$TmpDir/lazarus_build
 LazDeb=$CurDir/lazarus_${LazVersion}-${LazRelease}_$Arch.deb
 DebianSrcDir=$CurDir/debian_lazarus
 EtcSrcDir=$CurDir/linux
+LazSrcDir=../..
 LazDestDir=$LazBuildDir/usr/share/lazarus/${LazVersion}
 LazDestDirInstalled=/usr/share/lazarus/${LazVersion}
  
-FPCVersion=$($ppcbin -v | grep version| sed 's/.*\([0-9]\+\.[0-9]\+\.[0-9]\+\).*/\1/') 
+FPCVersion=$($ppcbin -v | grep version| sed 's/.*\([0-9]\+\.[0-9]\+\.[0-9]\+\).*/\1/')
 ChangeLogDate=`date --rfc-822`
 
+echo "ppcbin=$ppcbin"
+echo "LazVersion=$LazVersion"
+echo "FPCVersion=$FPCVersion"
+echo "ChangeLogDate=$ChangeLogDate"
+
 # download/export lazarus svn if needed
 if [ ! -f $SrcTGZ ]; then
   ./create_lazarus_export_tgz.sh $SrcTGZ
@@ -84,39 +124,51 @@ rm -rf $LazBuildDir
 
 # Unpack lazarus source
 echo "unpacking $SrcTGZ ..."
+ls -l $SrcTGZ
 mkdir -p $LazDestDir
 cd $LazDestDir
 tar xzf $CurDir/$SrcTGZ --strip 1
 cd -
+if [ "$UseCHMHelp" = "1" ]; then
+  echo
+  echo "Copying chm files"
+  cd $LazSrcDir/docs/chm
+  cp -v *.txt *.kwd *.chm *.xct $LazDestDir/docs/chm/
+  cd -
+fi
 
 # compile
+echo
 echo "Compiling may take a while ... =========================================="
 cd $LazDestDir
 MAKEOPTS="-Fl/opt/gnome/lib"
 if [ -n "$FPCCfg" ]; then
   MAKEOPTS="$MAKEOPTS -n @$FPCCfg"
 fi
-# build for default platform
-make lcl packager/registration ideintf bigidecomponents PP=$ppcbin OPT="$MAKEOPTS"
-# build gtk1 .ppu
-export LCL_PLATFORM=gtk
-make lcl packager/registration ideintf bigidecomponents PP=$ppcbin OPT="$MAKEOPTS"
-export LCL_PLATFORM=
-# build IDE
+echo "MAKEOPTS=$MAKEOPTS"
+# build
 export LCL_PLATFORM=$LCLWidgetset
-make bigide PP=$ppcbin USESVN2REVISIONINC=0 OPT="$MAKEOPTS"
-make lazbuilder PP=$ppcbin OPT="$MAKEOPTS"
-make tools PP=$ppcbin OPT="$MAKEOPTS"
+make bigide PP=$ppcbin OPT="$MAKEOPTS"
+# create directories for building alternative widgetsets
+mkdir -p units/${targetos}-linux/qt
+
 export LCL_PLATFORM=
 
 strip lazarus
 strip startlazarus
 strip lazbuild
-strip tools/apiwizz/apiwizz
 strip tools/lazres
 strip tools/updatepofiles
+strip tools/lrstolfm
+strip tools/svn2revisioninc
+if [ -f components/chmhelp/lhelp/lhelp ]; then
+  strip components/chmhelp/lhelp/lhelp
+fi
 cd -
 
+# get installed size in kb
+LazSize=$(du -s $LazDestDir | cut -f1)
+
 # create control file
 echo "========================================================================="
 echo "copying control file"
@@ -125,6 +177,7 @@ cat $DebianSrcDir/control$LCLWidgetset | \
   sed -e "s/FPCVERSION/$FPCVersion/g" \
       -e "s/LAZVERSION/$LazVersion/g" \
       -e "s/ARCH/$Arch/g" \
+      -e "s/LAZSIZE/$LazSize/g" \
   > $LazBuildDir/DEBIAN/control
 
 # copyright and changelog files
@@ -139,7 +192,7 @@ mkdir -p $LazBuildDir/usr/share/pixmaps
 mkdir -p $LazBuildDir/usr/share/applications
 mkdir -p $LazBuildDir/usr/share/mime/packages
 mkdir -p $LazBuildDir/usr/bin/
-install -m 644 $LazDestDir/images/ide_icon48x48.png $LazBuildDir/usr/share/pixmaps/lazarus.png
+install -m 644 $LazDestDir/images/icons/lazarus128x128.png $LazBuildDir/usr/share/pixmaps/lazarus.png
 install -m 644 $LazDestDir/install/lazarus.desktop $LazBuildDir/usr/share/applications/lazarus.desktop
 install -m 644 $LazDestDir/install/lazarus-mime.xml $LazBuildDir/usr/share/mime/packages/lazarus.xml
 ln -s $LazDestDirInstalled/lazarus $LazBuildDir/usr/bin/lazarus-ide
@@ -148,9 +201,9 @@ ln -s $LazDestDirInstalled/lazbuild $LazBuildDir/usr/bin/lazbuild
 
 # docs
 mkdir -p $LazBuildDir/usr/share/man/man1
-cat $LazDestDir/install/man/man1/lazbuild.1 | gzip > $LazBuildDir/usr/share/man/man1/lazbuild.1.gz
-cat $LazDestDir/install/man/man1/lazarus-ide.1 | gzip > $LazBuildDir/usr/share/man/man1/lazarus-ide.1.gz
-cat $LazDestDir/install/man/man1/startlazarus.1 | gzip > $LazBuildDir/usr/share/man/man1/startlazarus.1.gz
+for exe in lazbuild lazarus-ide startlazarus lazres svn2revisioninc updatepofiles; do
+cat $LazDestDir/install/man/man1/$exe.1 | gzip > $LazBuildDir/usr/share/man/man1/$exe.1.gz
+done
 
 # default configs
 mkdir -p $LazBuildDir/etc/lazarus
@@ -166,8 +219,7 @@ echo "fixing permissions ..."
 find $LazBuildDir -type d | xargs -d '\n' chmod 755  # this is needed, don't ask me why
 
 # postinst + postrm:
-# ToDo: update-mime-database /usr/share/mime
-# ToDo: update-desktop-database
+#  don't know
 
 # creating deb
 echo "creating deb ..."
